# Scramblery
A simple tool to scramble your images or only faces from images or videos

#### Purpose of Package
 The purpose of this package is the creating scrambled images from images or videos. User can either scramble the whole image or only facial area.
 This is very useful tool in psychology experiments especially if you are working with faces.

#### **Features**
- Scramble whole image with desired degree of scrambling
- Scramble only facial area with desired degree of scrambling
- Scramble only facial area in a video (useful for dynmaic stimuli) with desired degree of scrambling

#### Installation
- The package can be found in pypi. To install the package, run the following command in the terminal:
- `pip install scramblery`
#### Author
  -  Main Maintainer: [Enes ALTUN]

### Contributon
 Any kind of contribution is welcome. Thanks.